Class: Aws::SSMGuiConnect::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::SSMGuiConnect::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-ssmguiconnect/client.rb
Overview
An API client for SSMGuiConnect. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::SSMGuiConnect::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#delete_connection_recording_preferences(params = {}) ⇒ Types::DeleteConnectionRecordingPreferencesResponse
Deletes the preferences for recording RDP connections.
-
#get_connection_recording_preferences(params = {}) ⇒ Types::GetConnectionRecordingPreferencesResponse
Returns the preferences specified for recording RDP connections in the requesting Amazon Web Services account and Amazon Web Services Region.
-
#update_connection_recording_preferences(params = {}) ⇒ Types::UpdateConnectionRecordingPreferencesResponse
Updates the preferences for recording RDP connections.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-ssmguiconnect/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
617 618 619 |
# File 'lib/aws-sdk-ssmguiconnect/client.rb', line 617 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
620 621 622 |
# File 'lib/aws-sdk-ssmguiconnect/client.rb', line 620 def errors_module Errors end |
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
590 591 592 593 594 595 596 597 598 599 600 601 602 603 604 605 606 |
# File 'lib/aws-sdk-ssmguiconnect/client.rb', line 590 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::SSMGuiConnect') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-ssmguiconnect' context[:gem_version] = '1.18.0' Seahorse::Client::Request.new(handlers, context) end |
#delete_connection_recording_preferences(params = {}) ⇒ Types::DeleteConnectionRecordingPreferencesResponse
Deletes the preferences for recording RDP connections.
503 504 505 506 |
# File 'lib/aws-sdk-ssmguiconnect/client.rb', line 503 def delete_connection_recording_preferences(params = {}, = {}) req = build_request(:delete_connection_recording_preferences, params) req.send_request() end |
#get_connection_recording_preferences(params = {}) ⇒ Types::GetConnectionRecordingPreferencesResponse
Returns the preferences specified for recording RDP connections in the requesting Amazon Web Services account and Amazon Web Services Region.
528 529 530 531 |
# File 'lib/aws-sdk-ssmguiconnect/client.rb', line 528 def get_connection_recording_preferences(params = {}, = {}) req = build_request(:get_connection_recording_preferences, params) req.send_request() end |
#update_connection_recording_preferences(params = {}) ⇒ Types::UpdateConnectionRecordingPreferencesResponse
Updates the preferences for recording RDP connections.
581 582 583 584 |
# File 'lib/aws-sdk-ssmguiconnect/client.rb', line 581 def update_connection_recording_preferences(params = {}, = {}) req = build_request(:update_connection_recording_preferences, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
610 611 612 |
# File 'lib/aws-sdk-ssmguiconnect/client.rb', line 610 def waiter_names [] end |