Class: Aws::SSMGuiConnect::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::SSMGuiConnect::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-ssmguiconnect/client.rb
Overview
An API client for SSMGuiConnect. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::SSMGuiConnect::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#delete_connection_recording_preferences(params = {}) ⇒ Types::DeleteConnectionRecordingPreferencesResponse
Deletes the preferences for recording RDP connections.
-
#get_connection_recording_preferences(params = {}) ⇒ Types::GetConnectionRecordingPreferencesResponse
Returns the preferences specified for recording RDP connections in the requesting Amazon Web Services account and Amazon Web Services Region.
-
#update_connection_recording_preferences(params = {}) ⇒ Types::UpdateConnectionRecordingPreferencesResponse
Updates the preferences for recording RDP connections.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
473 474 475 |
# File 'lib/aws-sdk-ssmguiconnect/client.rb', line 473 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
619 620 621 |
# File 'lib/aws-sdk-ssmguiconnect/client.rb', line 619 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
622 623 624 |
# File 'lib/aws-sdk-ssmguiconnect/client.rb', line 622 def errors_module Errors end |
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
592 593 594 595 596 597 598 599 600 601 602 603 604 605 606 607 608 |
# File 'lib/aws-sdk-ssmguiconnect/client.rb', line 592 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::SSMGuiConnect') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-ssmguiconnect' context[:gem_version] = '1.17.0' Seahorse::Client::Request.new(handlers, context) end |
#delete_connection_recording_preferences(params = {}) ⇒ Types::DeleteConnectionRecordingPreferencesResponse
Deletes the preferences for recording RDP connections.
505 506 507 508 |
# File 'lib/aws-sdk-ssmguiconnect/client.rb', line 505 def delete_connection_recording_preferences(params = {}, = {}) req = build_request(:delete_connection_recording_preferences, params) req.send_request() end |
#get_connection_recording_preferences(params = {}) ⇒ Types::GetConnectionRecordingPreferencesResponse
Returns the preferences specified for recording RDP connections in the requesting Amazon Web Services account and Amazon Web Services Region.
530 531 532 533 |
# File 'lib/aws-sdk-ssmguiconnect/client.rb', line 530 def get_connection_recording_preferences(params = {}, = {}) req = build_request(:get_connection_recording_preferences, params) req.send_request() end |
#update_connection_recording_preferences(params = {}) ⇒ Types::UpdateConnectionRecordingPreferencesResponse
Updates the preferences for recording RDP connections.
583 584 585 586 |
# File 'lib/aws-sdk-ssmguiconnect/client.rb', line 583 def update_connection_recording_preferences(params = {}, = {}) req = build_request(:update_connection_recording_preferences, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
612 613 614 |
# File 'lib/aws-sdk-ssmguiconnect/client.rb', line 612 def waiter_names [] end |